// 	$Id: BoolNetBatchSwarm.h,v 1.2 1998/02/04 21:56:50 mgd Exp $	

#import <objectbase.h>
#import <activity.h>
#import <collections.h>
#import <simtools.h>
#import <stdio.h>
#import "BoolNetModelSwarm.h"

@interface BoolNetBatchSwarm: Swarm
{
  int displayFrequency;

  id displayActions;	
  id displaySchedule;
  id stopSchedule;
 
  BoolNetModelSwarm * boolNetModelSwarm;
  /*
  Averager * unhappinessAverager;	
  */
  FILE * outputFile;			
}

+createBegin: (id) aZone;
-buildObjects;
-buildActions;
-activateIn: (id) swarmContext;
-go;

// special message on ourselves to stop running.
-stopRunning;

// special data write method
-writeData;

@end
